Modules to create the name of the table from the row.
Modules
- row2cp
- Functions to create
RowToTableNameusing copiable types. - row2num
- Functions to create
RowToTableName.
Modules to create the name of the table from the row.
RowToTableName using copiable types.RowToTableName.