Module row2num

Module row2num 

Functions to create RowToTableName.

Functions

row2tname_row2num_new8i
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new8u
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new16i
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new16u
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new32i
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new32u
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new64i
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new64u
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new128i
Creates a RowToTableName which uses a number to create the name.
row2tname_row2num_new128u
Creates a RowToTableName which uses a number to create the name.